from accim.data.datawrangling import Table
import matplotlib.pyplot as plt
import time
start = time.time()

# making df
z = Table(frequency='hourly',
          sum_or_mean='sum',
          standard_outputs=True,
          level=['building'],
          level_sum_or_mean=['sum', 'mean'],
          match_cities=False,
          normalised_energy_units=True,
          rename_cols=True,
          energy_units_in_kwh=True,
          )


additional_list = [
    'Adaptive Cooling Setpoint Temperature_No Tolerance (°C)',
    'Adaptive Heating Setpoint Temperature_No Tolerance (°C)',
    'BLOCK1:ZONE2_EN16798-1 Running mean outdoor temperature (°C)',
    'Building_Total_Zone Thermostat Operative Temperature (°C) [mean]',
    'Building_Total_Cooling Energy Demand (kWh/m2) [summed]',
    'Building_Total_Heating Energy Demand (kWh/m2) [summed]',
]

custom_cols_list = additional_list

z.format_table(type_of_table='custom',
               custom_cols=custom_cols_list,
               split_epw_names=False
               )
print(*z.df.columns, sep='\n')


z.scatter_plot(
    type_of_graph='custom',
    vars_to_gather_rows=['EPW'],
    vars_to_gather_cols=['Adaptive Standard', 'Category'],
    data_on_x_axis='BLOCK1:ZONE2_EN16798-1 Running mean outdoor temperature (°C)',
    data_on_y_main_axis=[
       'Adaptive Cooling Setpoint Temperature_No Tolerance (°C)',
       'Adaptive Heating Setpoint Temperature_No Tolerance (°C)',
       'Building_Total_Zone Thermostat Operative Temperature (°C) [mean]',
               ]
               )
end = time.time()
print(end-start)


from accim.sim import accis

STlist = ['ex_ac', 'ex_mm']
outputlist = ['standard', 'simplified', 'timestep']

for i in STlist:
    for j in outputlist:
        accis.addAccis(ScriptType='ex_ac',
                       Outputs='standard',
                       EnergyPlus_version='ep95',
                       TempCtrl='temp',
                       ComfStand=[1],
                       CAT=[3],
                       ComfMod=[3],
                       NameSuffix=i+'_'+j,
                       confirmGen=True
                       )


from accim.data.datawrangling import Table
import time
start = time.time()

# making df
z = Table(frequency='hourly',
          sum_or_mean='sum',
          standard_outputs=True,
          level=['building'],
          level_sum_or_mean=['sum', 'mean'],
          match_cities=False,
          normalised_energy_units=True,
          rename_cols=True,
          energy_units_in_kwh=True,
          )
print(*z.df.columns, sep='\n')

additional_list = [
    'Site Outdoor Air Drybulb Temperature (°C)',
    'Building_Total_Cooling Energy Demand (kWh/m2) [summed]',
    'Building_Total_Heating Energy Demand (kWh/m2) [summed]',
]

custom_cols_list = additional_list

z.format_table(type_of_table='custom',
               custom_cols=custom_cols_list,
               split_epw_names=False
               )
print(*z.df.columns, sep='\n')


z.scatter_plot(type_of_graph='custom',
               vars_to_gather_rows=['EPW'],
               vars_to_gather_cols=['Adaptive Standard', 'Category'],
               data_on_x_axis='Site Outdoor Air Drybulb Temperature (°C)',
               data_on_y_main_axis=[
                   'Building_Total_Cooling Energy Demand (kWh/m2) [summed]',
                   'Building_Total_Heating Energy Demand (kWh/m2) [summed]',
               ],
               colorlist=[
                   'b',
                   'r'
               ],
               supxlabel='Outdoor temperature',
               supylabel='Energy demand'
               )
end = time.time()
print(end-start)




##

from accim.data.datawrangling import Table
import matplotlib.pyplot as plt
import time
start = time.time()

# making df
z = Table(frequency='daily',
          sum_or_mean='sum',
          standard_outputs=True,
          level=['building'],
          level_sum_or_mean=['sum'],
          match_cities=False,
          normalised_energy_units=True,
          rename_cols=True,
          energy_units_in_kwh=True,
          )


# print(*z.df.columns, sep='\n')


temp_list = []
# for col in z.df.columns:
#     for zone in z.occupied_zone_list:
#         if zone in col and 'Zone Thermostat Operative Temperature' in col:
#             temp_list.append(col)

additional_list = [
    'Building_Total_Cooling Energy Demand (kWh/m2) [summed]',
    'Building_Total_Heating Energy Demand (kWh/m2) [summed]',
]

custom_cols_list = temp_list + additional_list

z.format_table(type_of_table='custom',
               custom_cols=custom_cols_list,
               split_epw_names=False
               )

z.scatter_plot_adap_vs_stat(
    vars_to_gather_cols=['Adaptive Standard', 'Category'],
    vars_to_gather_rows=['EPW'],
    adap_vs_stat_data=additional_list,
    baseline='AS_CTE[CA_X',
    supxlabel='Static Energy Demand',
    supylabel='Adaptive Energy Demand',
    colorlist=[
        'b',
        'r'
    ],
    figname='temp_fig_adap vs stat en dem_daily_3',
    figsize=3,
    markersize=4,
    confirm_graph=True
)

end = time.time()
print(end-start)


from accim.data.datawrangling import Table

z = Table(frequency='runperiod',
          sum_or_mean='sum',
          standard_outputs=True,
          level=['block', 'building'],
          level_sum_or_mean=['sum'],
          match_cities=False,
          normalised_energy_units=False,
          rename_cols=True,
          energy_units_in_kwh=True
          )
print(*z.df.columns, sep='\n')

z.wrangled_table(
    vars_to_gather=[
        'Adaptive Standard',
        'Category'
        ],
    baseline='AS_CTE[CA_X',
    type_of_table='custom',
    custom_cols=[
        # 'Heating Energy Demand',
        # 'Cooling Energy Demand',
        # 'Total Energy Demand',
        'facility',
        'floor'
        ],
    comparison_cols=['absolute', 'relative']
)

z.wrangled_df.to_excel('export_test_wrangled.xlsx')
# z.wrangled_df
# print(*z.returndf().columns, sep='\n')

# z.df['EPW']
# print(z.df)

# z.df.to_excel('export_test.xlsx')


from accim.data.datawrangling import Table

z = Table(frequency='runperiod',
          sum_or_mean='sum',
          standard_outputs=True,
          level=['building'],
          level_sum_or_mean=['sum', 'mean'],
          match_cities=False,
          normalised_energy_units=True,
          rename_cols=True,
          energy_units_in_kwh=True,
          )
# z.df.to_excel('export_test_full_df.xlsx')
# print(*z.df.columns, sep='\n')
# print(*z.wrangled_df.columns, sep='\n')

z.format_table(type_of_table='energy demand',
               # custom_cols=custom_cols_list,
               split_epw_names=False
               )


z.wrangled_table(
    vars_to_gather=[
        'Adaptive Standard',
        'Category'
        ],
    baseline='AS_CTE[CA_X',
    comparison_cols=['absolute', 'relative']
)

z.wrangled_df.to_excel('export_test_wrangled_temp_3.xlsx')



from accim.sim import accis
accis.addAccis(ScriptType='ex_mm',
               Outputs='standard',
               EnergyPlus_version='ep95',
               TempCtrl='temp',
               ComfStand=[1],
               CAT=[1, 2, 3],
               ComfMod=[3],
               HVACmode=[2],
               VentCtrl=[0],
               confirmGen=True)


from accim.data.datawrangling import Table
import time
start = time.time()

# making df
z = Table(frequency='hourly',
          sum_or_mean='sum',
          standard_outputs=True,
          level=['building'],
          level_sum_or_mean=['sum', 'mean'],
          match_cities=False,
          normalised_energy_units=True,
          rename_cols=True,
          energy_units_in_kwh=True,
          )
print(*z.df.columns, sep='\n')

additional_list = [
    'Adaptive Cooling Setpoint Temperature_No Tolerance (°C)',
    'Adaptive Heating Setpoint Temperature_No Tolerance (°C)',
    'BLOCK1:ZONE2_EN16798-1 Running mean outdoor temperature (°C)',
    'Building_Total_Zone Thermostat Operative Temperature (°C) [mean]',
    'Building_Total_Cooling Energy Demand (kWh/m2) [summed]',
    'Building_Total_Heating Energy Demand (kWh/m2) [summed]',
]

custom_cols_list = additional_list

z.format_table(type_of_table='custom',
               custom_cols=custom_cols_list,
               split_epw_names=False
               )
print(*z.df.columns, sep='\n')

print(list(set(z.df['Adaptive Standard'])))
print(list(set(z.df['Category'])))

z.scatter_plot(type_of_graph='op temp vs rmot',
               vars_to_gather_rows=['EPW'],
               vars_to_gather_cols=['Adaptive Standard', 'Category'],
               # detailed_rows=['London_RCP85_2100', 'London_Present'],
               # detailed_cols=['AS_CTE[CA_X', 'AS_EN16798[CA_1'],
               data_on_x_axis='BLOCK1:ZONE2_EN16798-1 Running mean outdoor temperature (°C)',
               data_on_y_main_axis=[
                   'Adaptive Cooling Setpoint Temperature_No Tolerance (°C)',
                   'Adaptive Heating Setpoint Temperature_No Tolerance (°C)',
                   'Building_Total_Zone Thermostat Operative Temperature (°C) [mean]',
               ],
               # colorlist=[
               #     'b',
               #     'r'
               # ],
               # supxlabel='Outdoor temperature',
               # supylabel='Energy demand',
               figname='test_figure_rmot vs op temp_4',
               figsize=4,
               confirm_graph=True
               )
end = time.time()
print(end-start)

